@@ -1,6 +1,6 @@
 use 5.008001;
 
-our $VERSION = '0.034';
+our $VERSION = '0.035';
 package IO::LCDproc;
 
 ###############################################################################
@@ -49,9 +49,11 @@ sub initialize {
 	my $msgs;
 	print $fh "hello\n";
 	$msgs = <$fh>;
-	if($msgs =~ /lcd.+wid\s+(\d+)\s+hgt\s+(\d+)/){
+	if($msgs =~ /lcd.+wid\s+(\d+)\s+hgt\s+(\d+)\s+cellwid\s+(\d+)\s+cellhgt\s+(\d+)/){
 		$self->{width}  = $1;
 		$self->{height} = $2;
+		$self->{cellwidth} = $3;
+		$self->{cellheight} = $4;
 	} else {
 		croak "No stats reported...: $!";
 	}
@@ -65,6 +67,21 @@ sub initialize {
 	}
 }
 
+sub answer {
+	my $self = shift;
+	my $fh = $self->{lcd};
+	my $answ;
+        $answ = <$fh>;
+
+	return $answ;
+}
+
+sub flushAnswers {
+	my $self = shift;
+	while ($self->answer()) {}
+}
+
+
 ###############################################################################
 package IO::LCDproc::Screen;
 @IO::LCDproc::Screen::ISA = qw(IO::LCDproc);
@@ -78,7 +95,7 @@ sub new {
 	croak "No name for Screen: $!" unless($params{name});
 	my $self				= {};
 	$self->{name}		= $params{name};
-	$self->{heartbeat}= $params{heartbeat} || "on";
+	$self->{heartbeat}	= $params{heartbeat} || "on";
 	$self->{cmd}		= "screen_add $self->{name}\n";
 	$self->{widgets}	= undef;
 	bless ($self, $class);
@@ -94,6 +111,13 @@ sub add {
 	}
 }
 
+sub set_prio {
+	my $self = shift;
+	my $prio = shift;
+        my $fh = $self->{client}->{lcd};
+        print $fh "screen_set $self->{name} -priority $prio\n";
+}
+
 ###############################################################################
 package IO::LCDproc::Widget;
 @IO::LCDproc::Client::ISA = qw(IO::LCDproc);
@@ -194,6 +218,9 @@ IO::LCDproc - Perl extension to connect to an LCDproc ready display.
 	$second->set( data => "Second line" );
 	$third->set( data => "Third Line" );
 
+        $client->flushAnswers();
+
+
 =head1 DESCRIPTION
 
 Follow the example above. Pretty straight forward. You create a client, assign a screen,
@@ -223,6 +250,14 @@ It is the back engine of the module. It generates the connection to a ready list
 
 	Initializes client, screen and all the widgets  with the server.
 
+=item answer()
+
+	Reads an answer from the server
+
+=item flushAnswers()
+
+	Flushes all answers from the server (should be called regulary if you don't need the answers)
+
 =head2 IO::LCDproc::Screen
 
 =head3 METHODS
@@ -236,6 +271,17 @@ It is the back engine of the module. It generates the connection to a ready list
 
 	Adds the given widgets to this screen.
 
+=item set_prio( $prio )
+
+	Sets the screen priority with $prio one of
+
+	hidden		The screen will never be visible 
+	background	The screen is only visible when no normal info screens exists 
+	info		normal info screen, default priority 
+	foreground	an active client 
+	alert		The screen has an important message for the user. 
+	input		The client is doing interactive input. 
+
 =head2 IO::LCDproc::Widget
 
 =head3 METHODS
